@@ -6,17 +6,17 @@ from typing import Any, Dict, Optional
 import click
 
 from .click_common import command, format_output, EnumType
-from .device import Device, DeviceInfo, DeviceException
+from .device import Device, DeviceInfo, DeviceError, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
 MODEL_HUMIDIFIER_V1 = 'zhimi.humidifier.v1'
 MODEL_HUMIDIFIER_CA1 = 'zhimi.humidifier.ca1'
+MODEL_HUMIDIFIER_CB1 = 'zhimi.humidifier.cb1'
 
 AVAILABLE_PROPERTIES_COMMON = [
     'power',
     'mode',
-    'temp_dec',
     'humidity',
     'buzzer',
     'led_b',
@@ -27,8 +27,9 @@ AVAILABLE_PROPERTIES_COMMON = [
 ]
 
 AVAILABLE_PROPERTIES = {
-    MODEL_HUMIDIFIER_V1: AVAILABLE_PROPERTIES_COMMON + ['trans_level', 'button_pressed'],
-    MODEL_HUMIDIFIER_CA1: AVAILABLE_PROPERTIES_COMMON + ['speed', 'depth', 'dry'],
+    MODEL_HUMIDIFIER_V1: AVAILABLE_PROPERTIES_COMMON + ['temp_dec', 'trans_level', 'button_pressed'],
+    MODEL_HUMIDIFIER_CA1: AVAILABLE_PROPERTIES_COMMON + ['temp_dec', 'speed', 'depth', 'dry'],
+    MODEL_HUMIDIFIER_CB1: AVAILABLE_PROPERTIES_COMMON + ['temperature', 'speed', 'depth', 'dry']
 }
 
 
@@ -85,8 +86,10 @@ class AirHumidifierStatus:
     @property
     def temperature(self) -> Optional[float]:
         """Current temperature, if available."""
-        if self.data["temp_dec"] is not None:
+        if "temp_dec" in self.data and self.data["temp_dec"] is not None:
             return self.data["temp_dec"] / 10.0
+        if "temperature" in self.data and self.data["temperature"] is not None:
+            return self.data["temperature"]
         return None
 
     @property
@@ -285,8 +288,8 @@ class AirHumidifier(Device):
         # properties are divided into multiple requests
         _props_per_request = 15
 
-        # The  CA1 is limited to a single property per request
-        if self.model == MODEL_HUMIDIFIER_CA1:
+        # The CA1 and CB1 are limited to a single property per request
+        if self.model in [MODEL_HUMIDIFIER_CA1, MODEL_HUMIDIFIER_CB1]:
             _props_per_request = 1
 
         _props = properties.copy()
@@ -326,7 +329,14 @@ class AirHumidifier(Device):
     )
     def set_mode(self, mode: OperationMode):
         """Set mode."""
-        return self.send("set_mode", [mode.value])
+        try:
+            return self.send("set_mode", [mode.value])
+        except DeviceError as error:
+            # {'code': -6011, 'message': 'device_poweroff'}
+            if error.code == -6011:
+                self.on()
+                return self.send("set_mode", [mode.value])
+            raise
 
     @command(
         click.argument("brightness", type=EnumType(LedBrightness, False)),
@@ -335,7 +345,7 @@ class AirHumidifier(Device):
     )
     def set_led_brightness(self, brightness: LedBrightness):
         """Set led brightness."""
-        if self.model == MODEL_HUMIDIFIER_CA1:
+        if self.model in [MODEL_HUMIDIFIER_CA1, MODEL_HUMIDIFIER_CB1]:
             return self.send("set_led_b", [str(brightness.value)])
 
         return self.send("set_led_b", [brightness.value])
@@ -414,3 +424,10 @@ class AirHumidifierCA1(AirHumidifier):
                  debug: int = 0, lazy_discover: bool = True) -> None:
         super().__init__(ip, token, start_id, debug, lazy_discover,
                          model=MODEL_HUMIDIFIER_CA1)
+
+
+class AirHumidifierCB1(AirHumidifier):
+    def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
+                 debug: int = 0, lazy_discover: bool = True) -> None:
+        super().__init__(ip, token, start_id, debug, lazy_discover,
+                         model=MODEL_HUMIDIFIER_CB1)
