@@ -1,5 +1,6 @@
 import logging
 from collections import defaultdict
+from typing import Optional
 
 import click
 
@@ -10,6 +11,7 @@ _LOGGER = logging.getLogger(__name__)
 
 MODEL_AIRQUALITYMONITOR_V1 = 'zhimi.airmonitor.v1'
 MODEL_AIRQUALITYMONITOR_B1 = 'cgllc.airmonitor.b1'
+MODEL_AIRQUALITYMONITOR_S1 = 'cgllc.airmonitor.s1'
 
 AVAILABLE_PROPERTIES_COMMON = [
     'power', 'aqi', 'battery', 'usb_state', 'time_state',
@@ -17,9 +19,14 @@ AVAILABLE_PROPERTIES_COMMON = [
     'sensor_state'
 ]
 
+AVAILABLE_PROPERTIES_S1 = [
+    'battery', 'co2', 'humidity', 'pm25', 'temperature', 'tvoc'
+]
+
 AVAILABLE_PROPERTIES = {
     MODEL_AIRQUALITYMONITOR_V1: AVAILABLE_PROPERTIES_COMMON,
     MODEL_AIRQUALITYMONITOR_B1: AVAILABLE_PROPERTIES_COMMON,
+    MODEL_AIRQUALITYMONITOR_S1: AVAILABLE_PROPERTIES_S1,
 }
 
 
@@ -39,13 +46,20 @@ class AirQualityMonitorStatus:
         Response of a Xiaomi Air Quality Monitor (cgllc.airmonitor.b1):
 
         unknown.
+
+        Response of a Xiaomi Air Quality Monitor (cgllc.airmonitor.s1):
+
+        {'battery': 100, 'co2': 695, 'humidity': 62.1, 'pm25': 19.4, 'temperature': 27.4,
+         'tvoc': 254}
         """
         self.data = data
 
     @property
-    def power(self) -> str:
+    def power(self) -> Optional[str]:
         """Current power state."""
-        return self.data["power"]
+        if "power" in self.data and self.data["power"] is not None:
+            return self.data["power"]
+        return None
 
     @property
     def is_on(self) -> bool:
@@ -53,14 +67,18 @@ class AirQualityMonitorStatus:
         return self.power == "on"
 
     @property
-    def usb_power(self) -> bool:
+    def usb_power(self) -> Optional[bool]:
         """Return True if the device's usb is on."""
-        return self.data["usb_state"] == "on"
+        if "usb_state" in self.data and self.data["usb_state"] is not None:
+            return self.data["usb_state"] == "on"
+        return None
 
     @property
-    def aqi(self) -> int:
+    def aqi(self) -> Optional[int]:
         """Air quality index value. (0...600)."""
-        return self.data["aqi"]
+        if "aqi" in self.data and self.data["aqi"] is not None:
+            return self.data["aqi"]
+        return None
 
     @property
     def battery(self) -> int:
@@ -68,40 +86,95 @@ class AirQualityMonitorStatus:
         return self.data["battery"]
 
     @property
-    def display_clock(self) -> bool:
+    def display_clock(self) -> Optional[bool]:
         """Display a clock instead the AQI."""
-        return self.data["time_state"] == "on"
+        if "time_state" in self.data and self.data["time_state"] is not None:
+            return self.data["time_state"] == "on"
+        return None
 
     @property
-    def night_mode(self) -> bool:
+    def night_mode(self) -> Optional[bool]:
         """Return True if the night mode is on."""
-        return self.data["night_state"] == "on"
+        if "night_state" in self.data and self.data["night_state"] is not None:
+            return self.data["night_state"] == "on"
+        return None
 
     @property
-    def night_time_begin(self) -> str:
+    def night_time_begin(self) -> Optional[str]:
         """Return the begin of the night time."""
-        return self.data["night_beg_time"]
+        if "night_beg_time" in self.data and self.data["night_beg_time"] is not None:
+            return self.data["night_beg_time"]
+        return None
 
     @property
-    def night_time_end(self) -> str:
+    def night_time_end(self) -> Optional[str]:
         """Return the end of the night time."""
-        return self.data["night_end_time"]
+        if "night_end_time" in self.data and self.data["night_end_time"] is not None:
+            return self.data["night_end_time"]
+        return None
 
     @property
-    def sensor_state(self) -> str:
+    def sensor_state(self) -> Optional[str]:
         """Sensor state."""
-        return self.data["sensor_state"]
+        if "sensor_state" in self.data and self.data["sensor_state"] is not None:
+            return self.data["sensor_state"]
+        return None
+
+    @property
+    def co2(self) -> Optional[int]:
+        """Return co2 value (400...9999)ppm for MODEL_AIRQUALITYMONITOR_S1."""
+        if "co2" in self.data and self.data["co2"] is not None:
+            return self.data["co2"]
+        return None
+
+    @property
+    def humidity(self) -> Optional[float]:
+        """Return humidity value (0...100)% for MODEL_AIRQUALITYMONITOR_S1."""
+        if "humidity" in self.data and self.data["humidity"] is not None:
+            return self.data["humidity"]
+        return None
+
+    @property
+    def pm25(self) -> Optional[float]:
+        """Return pm2.5 value (0...999)μg/m³ for MODEL_AIRQUALITYMONITOR_S1."""
+        if "pm25" in self.data and self.data["pm25"] is not None:
+            return self.data["pm25"]
+        return None
+
+    @property
+    def temperature(self) -> Optional[float]:
+        """Return temperature value (-10...50)°C for MODEL_AIRQUALITYMONITOR_S1."""
+        if "temperature" in self.data and self.data["temperature"] is not None:
+            return self.data["temperature"]
+        return None
+
+    @property
+    def tvoc(self) -> Optional[int]:
+        """Return tvoc value for MODEL_AIRQUALITYMONITOR_S1."""
+        if "tvoc" in self.data and self.data["tvoc"] is not None:
+            return self.data["tvoc"]
+        return None
 
     def __repr__(self) -> str:
         s = "<AirQualityMonitorStatus power=%s, " \
             "aqi=%s, " \
             "battery=%s, " \
             "usb_power=%s, " \
+            "temperature=%s, " \
+            "humidity=%s, " \
+            "co2=%s, " \
+            "pm2.5=%s, " \
+            "tvoc=%s, " \
             "display_clock=%s>" % \
             (self.power,
              self.aqi,
              self.battery,
              self.usb_power,
+             self.temperature,
+             self.humidity,
+             self.co2,
+             self.pm25,
+             self.tvoc,
              self.display_clock)
         return s
 
@@ -113,17 +186,19 @@ class AirQualityMonitor(Device):
     """Xiaomi PM2.5 Air Quality Monitor."""
     def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
                  debug: int = 0, lazy_discover: bool = True,
-                 model: str = MODEL_AIRQUALITYMONITOR_V1) -> None:
+                 model: str = None) -> None:
         super().__init__(ip, token, start_id, debug, lazy_discover)
 
+        self.device_info = self.info()
+        if self.device_info and model is None:
+            model = self.device_info.model
+
         if model in AVAILABLE_PROPERTIES:
             self.model = model
         else:
             self.model = MODEL_AIRQUALITYMONITOR_V1
             _LOGGER.error("Device model %s unsupported. Falling back to %s.", model, self.model)
 
-        self.device_info = None
-
     @command(
         default_output=format_output(
             "",
@@ -152,8 +227,10 @@ class AirQualityMonitor(Device):
                 "count (%s) of received values.",
                 properties_count, values_count)
 
-        return AirQualityMonitorStatus(
-            defaultdict(lambda: None, zip(properties, values)))
+        if self.model == MODEL_AIRQUALITYMONITOR_S1:
+            return AirQualityMonitorStatus(defaultdict(lambda: None, values))
+        else:
+            return AirQualityMonitorStatus(defaultdict(lambda: None, zip(properties, values)))
 
     @command(
         default_output=format_output("Powering on"),
