@@ -83,6 +83,9 @@ class VacuumStatus:
             15: 'Docking',
             16: 'Going to target',
             17: 'Zoned cleaning',
+            18: 'Segment cleaning',
+            100: 'Charging complete',
+            101: 'Device offline',
         }
         try:
             return states[int(self.state_code)]
